@@ -58,7 +58,7 @@ private:
 
     bool vibrateActive;
     bool soundActive;
-    bool running;
+    bool proximity;
 
     int min, sec, set, reps;
     int MIN, SEC, SET, REPS;
@@ -83,6 +83,7 @@ private slots:
     void showNewProgram();
     void updateTime();
     void checkAcc(QString x);
+    void checkProximity(QString data);
     void shaked();
     void stopVibrate();
     void skipWait();
