@@ -100,20 +100,31 @@ void FoodWindow::createActions()
 
 void FoodWindow::load()
 {
-    QString kcal, tmp;
+    QList <int> list;
+    QString kcal, protein, carbohydrate, fat, tmp;
     QList <QString> settings;
     int remaining;
-    kcal.setNum(xml->getTodaysCalories());
 
+    list = xml->getTodaysCalories();
+    if(list.isEmpty())
+        return;
+
+    kcal.setNum(list.takeFirst());
+    protein.setNum(list.takeFirst());
+    carbohydrate.setNum(list.takeFirst());
+    fat.setNum(list.takeFirst());
+    qDebug() << "0";
     settings = xml->loadSettings();
     remaining = settings.takeLast().toInt() - kcal.toInt();
     tmp.setNum(remaining);
-
+    qDebug() << "1";
     if(remaining >= 0)
-        lblCalories->setText("You have eaten " + kcal + " kcal today (" + tmp + " left). \nYour mean kcal/day is 2800 kcal ");
+        lblCalories->setText("You have eaten " + kcal + " kcal today (" + tmp + " left). \nYour mean kcal/day is 2800 kcal " +
+                             "\nProtein: " + protein + "g. Carbohydrate: " + carbohydrate + "g. Fat: " +
+                             fat + "g.");
     else
         lblCalories->setText("You have eaten to much today. \nYour mean kcal/day is 2800 kcal");
-
+    qDebug() << "2";
 
 }
 
