@@ -26,6 +26,18 @@ private:
     QMaemo5ListPickSelector *selectorCalories;
     QStandardItemModel *modelCalories;
 
+    QMaemo5ValueButton *btnCarbohydrate;
+    QMaemo5ListPickSelector *selectorCarbohydrate;
+    QStandardItemModel *modelCarbohydrate;
+
+    QMaemo5ValueButton *btnProtein;
+    QMaemo5ListPickSelector *selectorProtein;
+    QStandardItemModel *modelProtein;
+
+    QMaemo5ValueButton *btnFat;
+    QMaemo5ListPickSelector *selectorFat;
+    QStandardItemModel *modelFat;
+
     QMaemo5ValueButton *btnType;
     QMaemo5ListPickSelector *selectorType;
     QStandardItemModel *modelType;
