@@ -34,19 +34,19 @@ public:
     QList <QString> getDates();
     QList < QList<QString> > getHistoryByDate(QString date);
 
-    void saveFood(QString name, QString type, QString kcal);
+    void saveFood(QString name, QString type, QString kcal, QString protein, QString carbohydrate, QString fat);
     QList<QString> openIngredients();
-    void saveEatenFood(QString kcal);
-    int getTodaysCalories();
+    void saveEatenFood(QString kcal, QString protein, QString carbohydrate, QString fat);
+    QList <int> getTodaysCalories();
     void getMeanCalories();
-    int getCaloriesByName(QString name);
+    QList <int> getCaloriesByName(QString name);
 
     void import(QString filename);
     void exportExercises(QModelIndexList name);
 
 private:
-    QDomElement createCaloriesNode ( QDomDocument &d, QString kcal, QString date);
-    QDomElement createFoodNode( QDomDocument &d, QString name, QString type, QString kcal);
+    QDomElement createCaloriesNode ( QDomDocument &d, QString kcal, QString protein, QString carbohydrate, QString fat, QString date);
+    QDomElement createFoodNode( QDomDocument &d, QString name, QString type, QString kcal, QString protein, QString carbohydrate, QString fat);
     QDomElement createExerciseNode( QDomDocument &d, QString name, QString group, QString muscle,
                                QString info);
     QDomElement createCardioNode( QDomDocument &d, QString name);
